pub struct ClientHandle<C, SM>where
    C: Cancellable,{ /* private fields */ }
Sending half of the peer’s connection.

Implementations

source

impl<C, SM> ClientHandle<C, SM>where C: Cancellable + 'static, <C as Cancellable>::Handle: Send,

source

pub async fn close(&self)

Closes both sending and receiving halves of the peer’s connection.

This method should only be called once. Consecutive calls to of this method have no effect.