Listener

Struct Listener 

pub struct Listener<CM, SM>
where CM: Send + Sync + 'static, SM: Send + Sync + 'static,
{ /* private fields */ }
Binds to a configured port and accepts incoming connections.

Implementations

Source

impl<CM, SM> Listener<CM, SM>
where CM: Send + Sync + 'static, SM: Send + Sync + 'static,

pub async fn bind( config: ListenerConfig, cancellation_token: CancellationToken, ) -> Result<Self, ListenerError>

Constructs the listener and binds it to the configured socket.

Arguments
  • config - configuration for the listener and all its clients.
  • cancellation_token - cancels the listener, unbinding it from the socket and sends a termination signal to all clients spawned from this listener.
Returns

Ok(Self) if it successfully bound to the socket. See ListenerError for errors descriptions.